==> jc-1.4.0.tar.gz: java/security/cert/LDAPCertStoreParameters.h <==
// public class java.security.cert.LDAPCertStoreParameters

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 95be04bc500e940b java_security_cert_LDAPCertStoreParameters

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_LDAPCertStoreParameters_H_
#define _JC_java_security_cert_LDAPCertStoreParameters_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_LDAPCertStoreParameters$sub_refs	_jc_java_security_cert_LDAPCertStoreParameters$sub_refs;
typedef struct _jc_java_security_cert_LDAPCertStoreParameters$sub_nonrefs	_jc_java_security_cert_LDAPCertStoreParameters$sub_nonrefs;
typedef struct _jc_java_security_cert_LDAPCertStoreParameters$refs	_jc_java_security_cert_LDAPCertStoreParameters$refs;
typedef struct _jc_java_security_cert_LDAPCertStoreParameters$nonrefs	_jc_java_security_cert_LDAPCertStoreParameters$nonrefs;
typedef struct _jc_java_security_cert_LDAPCertStoreParameters$object	_jc_java_security_cert_LDAPCertStoreParameters$object;

typedef struct _jc_java_security_cert_LDAPCertStoreParameters$fields_struct	_jc_java_security_cert_LDAPCertStoreParameters$fields_struct;
typedef const struct _jc_java_security_cert_LDAPCertStoreParameters$vmethods	_jc_java_security_cert_LDAPCertStoreParameters$vmethods;
typedef const struct _jc_java_security_cert_LDAPCertStoreParameters$vtable	_jc_java_security_cert_LDAPCertStoreParameters$vtable;
typedef const struct _jc_java_security_cert_LDAPCertStoreParameters$vtype	_jc_java_security_cert_LDAPCertStoreParameters$vtype;

// Class fields structure
struct _jc_java_security_cert_LDAPCertStoreParameters$fields_struct {
	jint	LDAP__5fPORT;
};
extern _jc_java_security_cert_LDAPCertStoreParameters$fields_struct _jc_java_security_cert_LDAPCertStoreParameters$class_fields;

// Constructors
extern void _jc_java_security_cert_LDAPCertStoreParameters$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *);
extern void _jc_java_security_cert_LDAPCertStoreParameters$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_security_cert_LDAPCertStoreParameters$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_LDAPCertStoreParameters$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *);
extern jint _jc_java_security_cert_LDAPCertStoreParameters$method$getPort$e10115a3e6b3cead(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_LDAPCertStoreParameters$method$getServerName$795ade2d1aae2aeb(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *);
extern struct _jc_java_lang_String$object *_jc_java_security_cert_LDAPCertStoreParameters$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *);

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_LDAPCertStoreParameters$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_cert_LDAPCertStoreParameters$method_info$getPort$e10115a3e6b3cead;
extern _jc_method _jc_java_security_cert_LDAPCertStoreParameters$method_info$getServerName$795ade2d1aae2aeb;
extern _jc_method _jc_java_security_cert_LDAPCertStoreParameters$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_LDAPCertStoreParameters$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *);
	jint	(*getPort$e10115a3e6b3cead)(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *);
	struct _jc_java_lang_String$object	*(*getServerName$795ade2d1aae2aeb)(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *);
};

// Vtable
struct _jc_java_security_cert_LDAPCertStoreParameters$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_LDAPCertStoreParameters$vmethods	java_security_cert_LDAPCertStoreParameters;
};

// Vtype
struct _jc_java_security_cert_LDAPCertStoreParameters$vtype {
	_jc_type			type;
	_jc_java_security_cert_LDAPCertStoreParameters$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_LDAPCertStoreParameters$sub_refs {
	struct _jc_java_lang_String$object	*serverName;
};

// Reference instance fields (object)
struct _jc_java_security_cert_LDAPCertStoreParameters$refs {
    _jc_java_security_cert_LDAPCertStoreParameters$sub_refs	java_security_cert_LDAPCertStoreParameters;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_LDAPCertStoreParameters$sub_nonrefs {
	jint	port;
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_LDAPCertStoreParameters$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_LDAPCertStoreParameters$sub_nonrefs	java_security_cert_LDAPCertStoreParameters;
};

// Object instance structure
struct _jc_java_security_cert_LDAPCertStoreParameters$object {
	_jc_java_security_cert_LDAPCertStoreParameters$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_LDAPCertStoreParameters$vtype	*vtype;
	_jc_java_security_cert_LDAPCertStoreParameters$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_LDAPCertStoreParameters$vtype _jc_java_security_cert_LDAPCertStoreParameters$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_LDAPCertStoreParameters, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_LDAPCertStoreParameters$class_object;

#endif	/* _JC_java_security_cert_LDAPCertStoreParameters_H_ */

==> jc-1.4.6.tar.gz: java/security/cert/LDAPCertStoreParameters.h <==
// public class java.security.cert.LDAPCertStoreParameters

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 95be04bc500e940b java_security_cert_LDAPCertStoreParameters

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_security_cert_LDAPCertStoreParameters_H_
#define _JC_java_security_cert_LDAPCertStoreParameters_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_security_cert_LDAPCertStoreParameters$sub_refs	_jc_java_security_cert_LDAPCertStoreParameters$sub_refs;
typedef struct _jc_java_security_cert_LDAPCertStoreParameters$sub_nonrefs	_jc_java_security_cert_LDAPCertStoreParameters$sub_nonrefs;
typedef struct _jc_java_security_cert_LDAPCertStoreParameters$refs	_jc_java_security_cert_LDAPCertStoreParameters$refs;
typedef struct _jc_java_security_cert_LDAPCertStoreParameters$nonrefs	_jc_java_security_cert_LDAPCertStoreParameters$nonrefs;
typedef struct _jc_java_security_cert_LDAPCertStoreParameters$object	_jc_java_security_cert_LDAPCertStoreParameters$object;

typedef struct _jc_java_security_cert_LDAPCertStoreParameters$fields_struct	_jc_java_security_cert_LDAPCertStoreParameters$fields_struct;
typedef const struct _jc_java_security_cert_LDAPCertStoreParameters$vmethods	_jc_java_security_cert_LDAPCertStoreParameters$vmethods;
typedef const struct _jc_java_security_cert_LDAPCertStoreParameters$vtable	_jc_java_security_cert_LDAPCertStoreParameters$vtable;
typedef const struct _jc_java_security_cert_LDAPCertStoreParameters$vtype	_jc_java_security_cert_LDAPCertStoreParameters$vtype;

// Class fields structure
struct _jc_java_security_cert_LDAPCertStoreParameters$fields_struct {
	jint	LDAP__5fPORT;
};
extern _jc_java_security_cert_LDAPCertStoreParameters$fields_struct _jc_java_security_cert_LDAPCertStoreParameters$class_fields;

// Constructors
extern void _jc_java_security_cert_LDAPCertStoreParameters$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_LDAPCertStoreParameters$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_security_cert_LDAPCertStoreParameters$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_security_cert_LDAPCertStoreParameters$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *) _JC_JCNI_ATTR;
extern jint _jc_java_security_cert_LDAPCertStoreParameters$method$getPort$e10115a3e6b3cead(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_LDAPCertStoreParameters$method$getServerName$795ade2d1aae2aeb(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_security_cert_LDAPCertStoreParameters$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_security_cert_LDAPCertStoreParameters$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_java_security_cert_LDAPCertStoreParameters$method_info$getPort$e10115a3e6b3cead;
extern _jc_method _jc_java_security_cert_LDAPCertStoreParameters$method_info$getServerName$795ade2d1aae2aeb;
extern _jc_method _jc_java_security_cert_LDAPCertStoreParameters$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_security_cert_LDAPCertStoreParameters$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *) _JC_JCNI_ATTR;
	jint	(*getPort$e10115a3e6b3cead)(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getServerName$795ade2d1aae2aeb)(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_security_cert_LDAPCertStoreParameters$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_security_cert_LDAPCertStoreParameters$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_LDAPCertStoreParameters$vmethods	java_security_cert_LDAPCertStoreParameters;
};

// Vtype
struct _jc_java_security_cert_LDAPCertStoreParameters$vtype {
	_jc_type			type;
	_jc_java_security_cert_LDAPCertStoreParameters$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_security_cert_LDAPCertStoreParameters$sub_refs {
	struct _jc_java_lang_String$object	*serverName;
};

// Reference instance fields (object)
struct _jc_java_security_cert_LDAPCertStoreParameters$refs {
    _jc_java_security_cert_LDAPCertStoreParameters$sub_refs	java_security_cert_LDAPCertStoreParameters;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_security_cert_LDAPCertStoreParameters$sub_nonrefs {
	jint	port;
};

// Non-reference instance fields (object)
struct _jc_java_security_cert_LDAPCertStoreParameters$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_LDAPCertStoreParameters$sub_nonrefs	java_security_cert_LDAPCertStoreParameters;
};

// Object instance structure
struct _jc_java_security_cert_LDAPCertStoreParameters$object {
	_jc_java_security_cert_LDAPCertStoreParameters$refs	refs[0];
	_jc_word		lockword;
	_jc_java_security_cert_LDAPCertStoreParameters$vtype	*vtype;
	_jc_java_security_cert_LDAPCertStoreParameters$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_security_cert_LDAPCertStoreParameters$vtype _jc_java_security_cert_LDAPCertStoreParameters$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_security_cert_LDAPCertStoreParameters, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_security_cert_LDAPCertStoreParameters$class_object;

#endif	/* _JC_java_security_cert_LDAPCertStoreParameters_H_ */
